==> Gbook-0.8.tar.gz: Gbook/lang/ext/nl_NL.php <==
<?php
$lang['friendlyname'] = 'Gastenboeken';
$lang['moddescription'] = 'Cre&euml;er en beheer gastenboeken en ontvang feedback van uw website bezoekers';
$lang['description'] = 'Ontvang feedback van uw website bezoekers';
$lang['postinstall'] = 'De Gbook module is succesvol ge&iuml;nstalleerd';
$lang['areyousure'] = 'Weet u zeker dat u dit wilt verwijderen?';
$lang['areyousuremulti'] = 'Weet u zeker dat u deze bulk-actie wilt uitvoeren?';
$lang['gbooks'] = 'Gastenboeken';
$lang['addgbook'] = 'Voeg gastenboek toe';
$lang['gbookadded'] = 'Gastenboek is toegevoegd';
$lang['editgbook'] = 'Bewerk gastenboek';
$lang['gbookupdated'] = 'Gastenboek is bijgewerkt';
$lang['gbookdeleted'] = 'Gastenboek is verwijderd';
$lang['entries_page'] = 'Aantal berichten per pagina';
$lang['prevent_post_twice'] = 'Voorkom opeenvolgende berichten van dezelfde bezoeker (gebaseerd op IP adres)';
$lang['allow_smilies'] = 'Sta het gebruik van Smileys toe';
$lang['allow_notifications'] = 'Sta het gebruik van gebruiker notificaties toe';
$lang['notification_subject'] = 'Notificatie email onderwerp';
$lang['notification_message'] = 'Notificatie email bericht';
$lang['submission_response'] = 'Respons na verzending formulier';
$lang['submission_response_spam'] = 'Respons na verzending formulier met spam-inhoud';
$lang['admin_notification_subject'] = 'Admin notificatie email onderwerp';
$lang['admin_notification_message'] = 'Admin notificatie email bericht';
$lang['required_fields'] = 'Vereiste velden op de Frontend';
$lang['import_csv'] = 'Importeer berichten via csv';
$lang['csv_format'] = 'csv formaat: &quot;author&quot;[string];&quot;email&quot;[string];&quot;title&quot;[string];&quot;message&quot;[string];&quot;ip&quot;[string];&quot;create_date&quot;[date/time:yyyy-mm-dd hh:mm:ss]';
$lang['smileys'] = 'Smileys ';
$lang['smiley'] = 'Smiley ';
$lang['addsmiley'] = 'Voeg Smiley toe';
$lang['id'] = 'ID ';
$lang['spamrate'] = 'Spam Rating ';
$lang['created'] = 'Gemaakt';
$lang['modified'] = 'Bewerkt';
$lang['itemadded'] = 'Bericht is toegevoegd';
$lang['edititem'] = 'Bewerk bericht';
$lang['itemupdated'] = 'Bericht is bijgewerkt';
$lang['itemdeleted'] = 'Bericht is verwijderd';
$lang['saveasham'] = 'Markeer bericht als &quot;Ham&quot;';
$lang['saveasspam'] = 'Markeer bericht als &quot;Spam&quot;';
$lang['deletefromham'] = 'Demarkeer bericht vanaf &quot;Ham&quot;';
$lang['deletefromspam'] = 'Demarkeer bericht vanaf &quot;Spam&quot;';
$lang['summary_tpl'] = 'lijst weergave';
$lang['detail_tpl'] = 'detail weergave';
$lang['form_tpl'] = 'frontend formulier';
$lang['default_summary_template'] = 'Standaard lijst sjabloon';
$lang['default_detail_template'] = 'Standaard detail sjabloon';
$lang['resetdefault'] = 'Laad/reset standaard sjabloon';
$lang['resetwarning'] = 'Weet u zeker dat u de sjabloon code wilt resetten naar de standaard?';
$lang['send_notifications_to'] = 'Emailadres waar notificaties van nieuwe berichten naartoe gestuurd worden';
$lang['max_spamrate_active'] = 'Maximale spamrating waarbij berichten automatisch op actief gezet worden na inzenden';
$lang['max_spamrate_active_help'] = 'tussen 0 en 1, standaard 0.6. Hoe lager deze waarde, hoe meer berichten niet standaard actief zijn.';
$lang['max_spamrate_notify'] = 'Maximale spamrating waarbij een notificatie email naar de admin wordt verstuurd';
$lang['max_spamrate_notify_help'] = 'tussen 0 en 1, standaard 0.9. Hoe hoger deze waarde, hoe groter de kans dat notificaties over spamberichten worden verzonden.';
$lang['max_spamrate_save'] = 'Maximale spamrating waarbij een bericht nog opgeslagen wordt';
$lang['max_spamrate_save_help'] = 'tussen 0 en 1, standaard 0.9. Hoe lager deze waarde, hoe groter de kans dat normale legitieme berichten niet opgeslagen worden.';
$lang['optionsupdated'] = 'De opties zijn succesvol bijgewerkt.';
$lang['entries'] = 'Berichten';
$lang['name'] = 'Naam';
$lang['email'] = 'Email ';
$lang['title'] = 'Titel';
$lang['message'] = 'Bericht';
$lang['notify'] = 'Stuur mij een email bij nieuwe berichten';
$lang['fe_submit'] = 'Verstuur';
$lang['validation_errors'] = 'Geef a.u.b. een correcte waarde voor de gemarkeerde velden en verstuur opnieuw.';
$lang['double_post'] = '<p>Bedankt voor uw bericht. Uw bericht was al toegevoegd aan ons gastenboek.</p>';
$lang['not_allowed_to_post_twice'] = '<p>Sorry. Vanwege spam-beveiliging is het niet mogelijk om twee berichten na elkaar te plaatsen. Excuses voor dit ongemak.</p>
<p>Probeert u het a.u.b. later nog een keer, of stuur ons een email zodat wij namens u het bericht aan ons gastenboek kunnen toevoegen.</p>';
$lang['submission_response_cnt'] = '<p>Bedankt voor uw bericht. Uw bericht is toegevoegd aan ons gastenboek.</p>';
$lang['submission_response_spam_cnt'] = '<p>Bedankt voor uw bericht.</p>
<p>Uw bericht lijkt echter spam te bevatten, daarom wordt het niet direct in ons gastenboek getoond, maar is eerst een controle vereist.</p>
<p>U zou ons hier eventueel van op de hoogte kunnen stellen door ons een emai te sturen.</p>';
$lang['admin_notification_subject_cnt'] = 'Nieuw bericht in uw gastenboek';
$lang['admin_notification_message_cnt'] = 'U heeft een nieuw bericht in uw {sitename} Gastenboek.

Zie: {root_url}';
$lang['help_action'] = 'Mogelijke waarden: <ul><li>&#039;default&#039; - voor lijstweergave van berichten</li><li>&#039;form&#039; - voor weergave van het formulier</li><li>&#039;detail&#039; - voor weergave van een enkel bericht, bijv. als zoekresultaat</li><ul>';
$lang['help_alias'] = 'Gebruik een ander gastenboek dan de standaard. Zie de Gastenboeken-tab, kolom &#039;Tags&#039;, voor de aliassen die gebruikt kunnen worden.';
$lang['help_entryid'] = 'Gebruik deze parameter samen met <code>action=&#039;detail&#039;</code> als u slechts &eacute;&eacute;n gastenboek bericht wilt tonen. Voor het laatst toegevoegde bericht, gebruik: <code>entryid=-1</code>';
$lang['help_template'] = 'Gebruik een ander sjabloon dan de standaard. Merk op dat sjablonen van het juiste type moeten zijn, in overeenstemming met de action parameter.';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>The Gbook module provides your site visitors a convenient way to give some feedback on your site. Messages can include smileys and your guestbook is effectively protected from spam without the necessity of using an annoying captcha.</p>
<h3>How Do I Use It</h3>
<p>To show the guestbook entries, just insert the module with the<code> {Gbook} </code>tag into the content section of a page.<br />
You can display a form with the<code> {Gbook action=&#039;form&#039;} </code>tag.</p>
<p>To get a quick start, a sample stylesheet has been installed which corresponds with the default module templates. Attach the stylesheet &#039;Gbook module&#039; to your page template(s) to give your guestbook a first good look.</p>

<h3>Edit Guestbook Entries</h3>
<p>Users with the &#039;Gbook: Use&#039; permission can edit guestbook entries in the backend.</p>

<h3>Spam Protection</h3>
<p>Gbook proudly uses the &quot;b8&quot; statistical (Bayesian) spam filter version 0.6, written by Tobias Leupold. This built-in spam protection system will only function after you have learned it how to interpret the messages by marking the first few entries as either &quot;Spam&quot; or &quot;Ham&quot;. If the system has learned enough good as well as enough bad words, it will give spam messages a rating somewhere near 1, and ham messages will be rated somewhere near 0. Messages with a rating of 0.50 could not be rated because of too few matching words.<br />Note that it won&#039;t be of use to manually mark entries as spam or ham, which are already rated as such.</p>
<p>If you want to know more of this excellent spam protection system, you can visit <a href="http://nasauber.de/opensource/b8/">nasauber.de</a>.</p>

<h3>Customisation</h3>
<p>The Guestbooks-tab in the admin section allows you to create more separate guestbooks. Each can have its own settings.<br />
Users must belong to a group with the &#039;Gbook: Modify&#039; permission to be able to create new guestbooks and to change settings.</p>

<h3>Import Guestbook Entries</h3>
<p>If you are migrating your site from another CMS or from another guestbook system, you probably might want to create a csv file containing all entries you have received in the past.</p>
<p>This csv file can easily be imported to Gbook, when it is formatted with fields in a specific order, separated by semicolons and enclosed by double quotes, like this:<br />
<code>&quot;author&quot;;&quot;email&quot;;&quot;title&quot;;&quot;message&quot;;&quot;ip&quot;;&quot;create_date&quot;</code></p>
<p>All fields are of type [string]. The field <em>create_date</em> needs to be formatted as &quot;yyyy-mm-dd hh:mm:ss&quot;</p>

<h3>Edit Gbook templates</h3>
<p>In order to edit templates, the user must belong to a group with the &#039;Modify Templates&#039; permission.</p>

<h3>Global Gbook Options</h3>
<p>To edit the global Gbook options, the user must belong to a group with the &#039;Modify Site Preferences&#039; permission.</p>

<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>FAQs, extended module help and Troubleshooting can be found in the <a href="http://wiki.cmsms.nl/index.php/Gbook">Gbook Wiki Documentation</a>.</li>
<li>For the latest version of this module or to file a Feature Request or Bug Report, please visit the Module Forge
<a href="http://dev.cmsmadesimple.org/projects/gbook/">Gbook Page</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>. You are warmly invited to open a new topic if you didn&#039;t find an answer to your question.</li>
<li>Lastly, you may have some success emailing the author directly.</li>
</ul>

<h3>Feedback</h3>
<p>If you enjoy this module, use it on a commercial website or would like to encourage future development, you might consider just a small donation.<br />Or leave a message in the <a href="http://forum.cmsmadesimple.org/">Gbook forum topic</a>. Any kind of feedback will be much appreciated.</p>
';
$lang['utmz'] = '156861353.1355667847.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/search.php|utmcmd=referral';
$lang['utma'] = '156861353.594691262.1355667847.1355667847.1355667847.1';
$lang['qca'] = 'P0-802263609-1268423862699';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> Gbook-1.0.1.tar.gz: Gbook/lang/ext/nl_NL.php <==
<?php
$lang['friendlyname'] = 'Gastenboeken';
$lang['moddescription'] = 'Cre&euml;er en beheer gastenboeken en ontvang feedback van uw website bezoekers';
$lang['description'] = 'Ontvang feedback van uw website bezoekers';
$lang['postinstall'] = 'De Gbook module is succesvol ge&iuml;nstalleerd. Zie de admin Content sectie: &#039;%s&#039;.';
$lang['areyousure'] = 'Weet u zeker dat u dit wilt verwijderen?';
$lang['areyousuremulti'] = 'Weet u zeker dat u deze bulk-actie wilt uitvoeren?';
$lang['gbooks'] = 'Gastenboeken';
$lang['addgbook'] = 'Voeg gastenboek toe';
$lang['gbookadded'] = 'Gastenboek is toegevoegd';
$lang['editgbook'] = 'Bewerk gastenboek';
$lang['gbookupdated'] = 'Gastenboek is bijgewerkt';
$lang['gbookdeleted'] = 'Gastenboek is verwijderd';
$lang['entries_page'] = 'Aantal berichten per pagina';
$lang['prevent_post_twice'] = 'Voorkom opeenvolgende berichten van dezelfde bezoeker (gebaseerd op IP adres)';
$lang['allow_smilies'] = 'Sta het gebruik van Smileys toe';
$lang['allow_notifications'] = 'Sta het gebruik van gebruiker notificaties toe';
$lang['notification_subject'] = 'Notificatie email onderwerp';
$lang['notification_message'] = 'Notificatie email bericht';
$lang['submission_response'] = 'Respons na verzending formulier';
$lang['submission_response_spam'] = 'Respons na verzending formulier met spam-inhoud';
$lang['admin_notification_subject'] = 'Admin notificatie email onderwerp';
$lang['admin_notification_message'] = 'Admin notificatie email bericht';
$lang['required_fields'] = 'Vereiste velden op de Frontend';
$lang['import_csv'] = 'Importeer berichten via csv';
$lang['csv_format'] = 'csv formaat: &quot;author&quot;[string];&quot;email&quot;[string];&quot;title&quot;[string];&quot;message&quot;[string];&quot;ip&quot;[string];&quot;create_date&quot;[date/time:yyyy-mm-dd hh:mm:ss]';
$lang['smileys'] = 'Smileys ';
$lang['smiley'] = 'Smiley ';
$lang['addsmiley'] = 'Voeg Smiley toe';
$lang['id'] = 'ID ';
$lang['spamrate'] = 'Spam Rating ';
$lang['created'] = 'Gemaakt';
$lang['modified'] = 'Bewerkt';
$lang['itemadded'] = 'Bericht is toegevoegd';
$lang['edititem'] = 'Bewerk bericht';
$lang['itemupdated'] = 'Bericht is bijgewerkt';
$lang['itemdeleted'] = 'Bericht is verwijderd';
$lang['saveasham'] = 'Markeer bericht als &quot;Ham&quot;';
$lang['saveasspam'] = 'Markeer bericht als &quot;Spam&quot;';
$lang['deletefromham'] = 'Demarkeer bericht vanaf &quot;Ham&quot;';
$lang['deletefromspam'] = 'Demarkeer bericht vanaf &quot;Spam&quot;';
$lang['summary_tpl'] = 'lijst weergave';
$lang['detail_tpl'] = 'detail weergave';
$lang['form_tpl'] = 'frontend formulier';
$lang['default_summary_template'] = 'Standaard lijst sjabloon';
$lang['default_detail_template'] = 'Standaard detail sjabloon';
$lang['resetdefault'] = 'Laad/reset standaard sjabloon';
$lang['resetwarning'] = 'Weet u zeker dat u de sjabloon code wilt resetten naar de standaard?';
$lang['send_notifications_to'] = 'Emailadres waar notificaties van nieuwe berichten naartoe gestuurd worden';
$lang['max_spamrate_active'] = 'Maximale spamrating waarbij berichten automatisch op actief gezet worden na inzenden';
$lang['max_spamrate_active_help'] = 'tussen 0 en 1, standaard 0.6. Hoe lager deze waarde, hoe meer berichten niet standaard actief zijn.';
$lang['max_spamrate_notify'] = 'Maximale spamrating waarbij een notificatie email naar de admin wordt verstuurd';
$lang['max_spamrate_notify_help'] = 'tussen 0 en 1, standaard 0.9. Hoe hoger deze waarde, hoe groter de kans dat notificaties over spamberichten worden verzonden.';
$lang['max_spamrate_save'] = 'Maximale spamrating waarbij een bericht nog opgeslagen wordt';
$lang['max_spamrate_save_help'] = 'tussen 0 en 1, standaard 0.9. Hoe lager deze waarde, hoe groter de kans dat normale legitieme berichten niet opgeslagen worden.';
$lang['badwords'] = 'Maskeer ondeugende woorden (komma gescheiden)';
$lang['optionsupdated'] = 'De opties zijn succesvol bijgewerkt.';
$lang['entries'] = 'Berichten';
$lang['name'] = 'Naam';
$lang['email'] = 'Email ';
$lang['title'] = 'Titel';
$lang['message'] = 'Bericht';
$lang['notify'] = 'Stuur mij een email bij nieuwe berichten';
$lang['fe_submit'] = 'Verstuur';
$lang['validation_errors'] = 'Geef a.u.b. een correcte waarde voor de gemarkeerde velden en verstuur opnieuw.';
$lang['double_post'] = '<p>Bedankt voor uw bericht. Uw bericht was al toegevoegd aan ons gastenboek.</p>';
$lang['not_allowed_to_post_twice'] = '<p>Sorry. Vanwege spam-beveiliging is het niet mogelijk om twee berichten na elkaar te plaatsen. Excuses voor dit ongemak.</p>
<p>Probeert u het a.u.b. later nog een keer, of stuur ons een email zodat wij namens u het bericht aan ons gastenboek kunnen toevoegen.</p>';
$lang['submission_response_cnt'] = '<p>Bedankt voor uw bericht. Uw bericht is toegevoegd aan ons gastenboek.</p>';
$lang['submission_response_spam_cnt'] = '<p>Bedankt voor uw bericht.</p>
<p>Uw bericht lijkt echter spam te bevatten, daarom wordt het niet direct in ons gastenboek getoond, maar is eerst een controle vereist.</p>
<p>U zou ons hier eventueel van op de hoogte kunnen stellen door ons een emai te sturen.</p>';
$lang['admin_notification_subject_cnt'] = 'Nieuw bericht in uw gastenboek';
$lang['admin_notification_message_cnt'] = 'U heeft een nieuw bericht in uw {sitename} Gastenboek.

Zie: {root_url}';
$lang['help_action'] = 'Mogelijke waarden: <ul><li>&#039;default&#039; - voor lijstweergave van berichten</li><li>&#039;form&#039; - voor weergave van het formulier</li><li>&#039;detail&#039; - voor weergave van een enkel bericht, bijv. als zoekresultaat</li></ul>';
$lang['help_alias'] = 'Gebruik een ander gastenboek dan de standaard. Zie de Gastenboeken-tab, kolom &#039;Tags&#039;, voor de aliassen die gebruikt kunnen worden.';
$lang['help_entryid'] = 'Gebruik deze parameter samen met <code>action=&#039;detail&#039;</code> als u slechts &eacute;&eacute;n gastenboek bericht wilt tonen. Voor het laatst toegevoegde bericht, gebruik: <code>entryid=-1</code>';
$lang['help_template'] = 'Gebruik een ander sjabloon dan de standaard. Merk op dat sjablonen van het juiste type moeten zijn, in overeenstemming met de action parameter.';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>The Gbook module provides your site visitors a convenient way to give some feedback on your site. Messages can include smileys and your guestbook is effectively protected from spam without the necessity of using an annoying captcha.</p>
<h3>How Do I Use It</h3>
<p>To show the guestbook entries, just insert the module with the<code> {Gbook} </code>tag into the content section of a page.<br />
You can display a form with the<code> {Gbook action=&#039;form&#039;} </code>tag.</p>
<p>To get a quick start, a sample stylesheet has been installed which corresponds with the default module templates. Attach the stylesheet &#039;Gbook module&#039; to your page template(s) to give your guestbook a first good look.</p>

<h3>Edit Guestbook Entries</h3>
<p>Users with the &#039;Gbook: Use&#039; permission can edit guestbook entries in the backend.</p>

<h3>Spam Protection</h3>
<p>Gbook proudly uses the &quot;b8&quot; statistical (Bayesian) spam filter version 0.6, written by Tobias Leupold. This built-in spam protection system will only function after you have learned it how to interpret the messages by marking the first few entries as either &quot;Spam&quot; or &quot;Ham&quot;. If the system has learned enough good as well as enough bad words, it will give spam messages a rating somewhere near 1, and ham messages will be rated somewhere near 0. Messages with a rating of 0.50 could not be rated because of too few matching words.<br />Note that it won&#039;t be of use to manually mark entries as spam or ham, which are already rated as such.</p>
<p>If you want to know more of this excellent spam protection system, you can visit <a href="http://nasauber.de/opensource/b8/">nasauber.de</a>.</p>

<h3>Customisation</h3>
<p>The Guestbooks-tab in the admin section allows you to create more separate guestbooks. Each can have its own settings.<br />
Users must belong to a group with the &#039;Gbook: Modify&#039; permission to be able to create new guestbooks and to change settings.</p>

<h3>Import Guestbook Entries</h3>
<p>If you are migrating your site from another CMS or from another guestbook system, you probably might want to create a csv file containing all entries you have received in the past.</p>
<p>This csv file can easily be imported to Gbook, when it is formatted with fields in a specific order, separated by semicolons and enclosed by double quotes, like this:<br />
<code>&quot;author&quot;;&quot;email&quot;;&quot;title&quot;;&quot;message&quot;;&quot;ip&quot;;&quot;create_date&quot;</code></p>
<p>All fields are of type [string]. The field <em>create_date</em> needs to be formatted as &quot;yyyy-mm-dd hh:mm:ss&quot;</p>

<h3>Edit Gbook templates</h3>
<p>In order to edit templates, the user must belong to a group with the &#039;Modify Templates&#039; permission.</p>

<h3>Global Gbook Options</h3>
<p>To edit the global Gbook options, the user must belong to a group with the &#039;Modify Site Preferences&#039; permission.</p>

<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>FAQs, extended module help and Troubleshooting can be found in the <a href="http://wiki.cmsms.nl/index.php/Gbook">Gbook Wiki Documentation</a>.</li>
<li>For the latest version of this module or to file a Feature Request or Bug Report, please visit the Module Forge
<a href="http://dev.cmsmadesimple.org/projects/gbook/">Gbook Page</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>. You are warmly invited to open a new topic if you didn&#039;t find an answer to your question.</li>
<li>Lastly, you may have some success emailing the author directly.</li>
</ul>

<h3>Feedback</h3>
<p>If you enjoy this module, use it on a commercial website or would like to encourage future development, you might consider just a small donation.<br />Or leave a message in the <a href="http://forum.cmsmadesimple.org/viewtopic.php?f=7&amp;t=64460">Gbook forum topic</a>. Any kind of feedback will be much appreciated.</p>
';
$lang['utmz'] = '57867837.1345118961.1699.18.utmcsr=cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
$lang['utma'] = '57867837.1815583785146351600.1249721294.1355688860.1355769343.1709';
$lang['qca'] = 'P0-802263609-1268423862699';
$lang['utmb'] = '57867837.71.10.1355829120';
$lang['utmc'] = '57867837';
?>
